┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/infosidebarpage.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/infosidebarpage.h')
-rw-r--r--src/infosidebarpage.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/infosidebarpage.h b/src/infosidebarpage.h
index ef451169c..97d63afa9 100644
--- a/src/infosidebarpage.h
+++ b/src/infosidebarpage.h
@@ -144,11 +144,11 @@ private:
bool convertMetaInfo(const QString& key, QString& text) const;
/**
* Returns the URL of the file where the preview and meta information
* should be received, if InfoSidebarPage::showMultipleSelectionInfo()
* returns false.
*/
- KUrl fileUrl() const;
+ KFileItem fileItem() const;
/**
* Returns true, if the meta information should be shown for
@@ -144,11 +144,11 @@ private:
bool convertMetaInfo(const QString& key, QString& text) const;
/**
- * Returns the URL of the file where the preview and meta information
+ * Returns the item for file where the preview and meta information
* should be received, if InfoSidebarPage::showMultipleSelectionInfo()
* returns false.